@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# Copyright (c) 2015 Ultimaker B.V.
+# Copyright (c) 2018 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
 
 import argparse
@@ -27,7 +27,7 @@ known_args = vars(parser.parse_known_args()[0])
 if not known_args["debug"]:
     def get_cura_dir_path():
         if Platform.isWindows():
-            return os.path.expanduser("~/AppData/Roaming/cura/")
+            return os.path.expanduser("~/AppData/Roaming/cura")
         elif Platform.isLinux():
             return os.path.expanduser("~/.local/share/cura")
         elif Platform.isOSX():
@@ -46,11 +46,15 @@ import faulthandler
 if Platform.isLinux(): # Needed for platform.linux_distribution, which is not available on Windows and OSX
     # For Ubuntu: https://bugs.launchpad.net/ubuntu/+source/python-qt4/+bug/941826
     linux_distro_name = platform.linux_distribution()[0].lower()
-    # TODO: Needs a "if X11_GFX == 'nvidia'" here. The workaround is only needed on Ubuntu+NVidia drivers. Other drivers are not affected, but fine with this fix.
-    import ctypes
-    from ctypes.util import find_library
-    libGL = find_library("GL")
-    ctypes.CDLL(libGL, ctypes.RTLD_GLOBAL)
+    # The workaround is only needed on Ubuntu+NVidia drivers. Other drivers are not affected, but fine with this fix.
+    try:
+        import ctypes
+        from ctypes.util import find_library
+        libGL = find_library("GL")
+        ctypes.CDLL(libGL, ctypes.RTLD_GLOBAL)
+    except:
+        # GLES-only systems (e.g. ARM Mali) do not have libGL, ignore error
+        pass
 
 # When frozen, i.e. installer version, don't let PYTHONPATH mess up the search path for DLLs.
 if Platform.isWindows() and hasattr(sys, "frozen"):
